package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.QueryConfig;

/**
 * 查询配置Service接口
 * 
 * @author 博曼
 * @date 2021-12-27
 */
public interface IQueryConfigService 
{
    /**
     * 查询查询配置
     * 
     * @param configId 查询配置主键
     * @return 查询配置
     */
    public QueryConfig selectQueryConfigByConfigId(Long configId);

    /**
     * 查询查询配置列表
     * 
     * @param queryConfig 查询配置
     * @return 查询配置集合
     */
    public List<QueryConfig> selectQueryConfigList(QueryConfig queryConfig);

    /**
     * 新增查询配置
     * 
     * @param queryConfig 查询配置
     * @return 结果
     */
    public AjaxResult insertQueryConfig(QueryConfig queryConfig);

    /**
     * 修改查询配置
     * 
     * @param queryConfig 查询配置
     * @return 结果
     */
    public AjaxResult updateQueryConfig(QueryConfig queryConfig);

    /**
     * 批量删除查询配置
     * 
     * @param configIds 需要删除的查询配置主键集合
     * @return 结果
     */
    public int deleteQueryConfigByConfigIds(Long[] configIds);

    /**
     * 删除查询配置信息
     * 
     * @param configId 查询配置主键
     * @return 结果
     */
    public int deleteQueryConfigByConfigId(Long configId);
}
